@@ -13,12 +13,13 @@
 #define __must_check
 #endif
 
-#ifndef _weak
-#ifndef __CYGWIN__
-#define _weak	__attribute__((weak))
-#else
-#define _weak
-#endif
-#endif
+/*
+ * Mark unused variables passed to ops functions as unused, to silence gcc
+ */
+#define fio_unused	__attribute__((__unused__))
+#define fio_init	__attribute__((constructor))
+#define fio_exit	__attribute__((destructor))
+
+#define fio_unlikely(x)	__builtin_expect(!!(x), 0)
 
 #endif
