@@ -19,6 +19,7 @@ enum {
 	FD_PROFILE,
 	FD_TIME,
 	FD_NET,
+	FD_RATE,
 	FD_DEBUG_MAX,
 };
 
@@ -27,6 +28,7 @@ extern unsigned int fio_debug_jobno, *fio_debug_jobp;
 #ifdef FIO_INC_DEBUG
 struct debug_level {
 	const char *name;
+	const char *help;
 	unsigned long shift;
 	unsigned int jobno;
 };
